personal/q3k/shipstuck: add TOWED

Change-Id: I3348fc0730a66c3c64df00f6d3051656bf12e587
diff --git a/personal/q3k/shipstuck/proto/shipstuck.proto b/personal/q3k/shipstuck/proto/shipstuck.proto
index f0836e1..a76d199 100644
--- a/personal/q3k/shipstuck/proto/shipstuck.proto
+++ b/personal/q3k/shipstuck/proto/shipstuck.proto
@@ -23,8 +23,9 @@
         STUCKNESS_STUCK = 1;
         STUCKNESS_FREE = 2;
         STUCKNESS_UNKNOWN = 3;
+        STUCKNESS_TOWED = 4;
     };
     Stuckness current = 2;
     // If STUCK, how many nanoseconds have elapsed since the whoopsie?
     int64 elapsed = 3;
 }
@@ -23,8 +23,9 @@
     };
     Stuckness current = 2;
-    // If STUCK, how many nanoseconds have elapsed since the whoopsie?
+    // If STUCK or TOWED, how many nanoseconds have elapsed since the whoopsie?
     int64 elapsed = 3;
 }